@@ -662,6 +662,18 @@ export default {
             return (await axios.get(orthancApiUrl + "auth/audit-logs?" + getArguments.toString())).data;
         }
     },
+    async getWorklists() {
+        return (await axios.get(orthancApiUrl + "worklists?format=Full")).data;
+    },
+    async deleteWorklist(worklistId) {
+        await axios.delete(orthancApiUrl + "worklists/" + worklistId);
+    },
+    async createWorklist(wlTags) {
+        return (await axios.post(orthancApiUrl + "worklists/create", {"Tags": wlTags})).data;
+    },
+    async updateWorklist(worklistId, wlTags) {
+        return (await axios.put(orthancApiUrl + "worklists/" + worklistId, {"Tags": wlTags})).data;
+    },
 
     ////////////////////////////////////////// HELPERS
     getOsimisViewerUrl(level, resourceOrthancId) {
@@ -727,6 +739,16 @@ export default {
         // stl/app/o3dv.html
         // stl/app/three.html
     },
+   getWeasisViewerUrl(resourceDicomUid) {
+        const dicomWebRootUrl = new URL(orthancApiUrl + "dicom-web", window.location.origin);
+        const parts = ["$dicom:rs", "--url", `"${dicomWebRootUrl.toString()}"`, "-r", `"studyUID=${resourceDicomUid}"`];
+        const url = "weasis://?" + parts.map(v => encodeURIComponent(v)).join("+");
+        return url
+    },
+    getWeasisViewerUrlForBulkStudies(studiesDicomIds) {
+        const studyUids = studiesDicomIds.join(",");
+        return this.getWeasisViewerUrl(studyUids);
+    },
     getInstancePreviewUrl(orthancId) {
         return orthancApiUrl + "instances/" + orthancId + "/preview";
     },
