@@ -2,6 +2,7 @@ import { createRouter, createWebHashHistory } from 'vue-router'
 import Settings from './components/Settings.vue'
 import SettingsLabels from './components/SettingsLabels.vue'
 import SettingsPermissions from './components/SettingsPermissions.vue'
+import Worklists from './components/Worklists.vue'
 import AuditLogs from './components/AuditLogs.vue'
 import StudyList from './components/StudyList.vue'
 import SideBar from './components/SideBar.vue'
@@ -10,16 +11,6 @@ import { baseOe2Url } from "./globalConfigurations"
 
 console.log('Base URL for router: ', baseOe2Url);
 
-function removeKeyCloakStates(to, from, next) {
-  if (to.path.includes("&state=")) {
-    // the router does not recognize the &state=... after a redirect from KeyCloak -> simply block it (it works but I don't really understand why !)
-    console.log("removeKeyCloakStates", to, from);
-    next(false);
-  } else {
-    next();
-  }
-}
-
 export const router = createRouter({
   history: createWebHashHistory(baseOe2Url),
   routes: [
@@ -40,6 +31,14 @@ export const router = createRouter({
       },
       name: 'local-studies-list'
     },
+    {
+      path: '/worklists',
+      components: {
+        SideBarView: SideBar,
+        ContentView: Worklists,
+      },
+      name: 'worklists'
+    },
     {
       path: '/settings',
       components: {
@@ -74,7 +73,6 @@ export const router = createRouter({
     },
     {
       path: '/:pathMatch(.*)',
-      beforeEnter: removeKeyCloakStates,
       components: {
         SideBarView: SideBar,
         ContentView: NotFound,
